import { AccountAddress, AutomaticTokenBridge, ChainAddress, ChainId, ChainsConfig, Contracts, Network, TokenAddress } from '@wormhole-foundation/connect-sdk';
import { SolanaChains, SolanaPlatformType, SolanaUnsignedTransaction } from '@wormhole-foundation/connect-sdk-solana';
import { Program } from '@project-serum/anchor';
import { Connection, PublicKey } from '@solana/web3.js';
import { Platform } from '@wormhole-foundation/sdk-base/src';
import { TokenBridgeRelayer as TokenBridgeRelayerContract } from './automaticTokenBridgeType';
import '@wormhole-foundation/connect-sdk-solana-core';
export declare class SolanaAutomaticTokenBridge<N extends Network, C extends SolanaChains> implements AutomaticTokenBridge<N, SolanaPlatformType, C> {
    readonly network: N;
    readonly chain: C;
    readonly connection: Connection;
    readonly contracts: Contracts;
    readonly chainId: ChainId;
    readonly coreBridgeProgramId: PublicKey;
    readonly tokenBridgeProgramId: PublicKey;
    readonly tokenBridgeRelayer: Program<TokenBridgeRelayerContract>;
    private constructor();
    static fromRpc<N extends Network>(connection: Connection, config: ChainsConfig<N, Platform>): Promise<SolanaAutomaticTokenBridge<N, SolanaChains>>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, token: TokenAddress<C>, amount: bigint, nativeGas?: bigint | undefined): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    redeem(sender: AccountAddress<C>, vaa: AutomaticTokenBridge.VAA): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    getRelayerFee(sender: AccountAddress<C>, recipient: ChainAddress, token: TokenAddress<C>): Promise<bigint>;
    maxSwapAmount(token: TokenAddress<C>): Promise<bigint>;
    nativeTokenAmount(token: TokenAddress<C>, amount: bigint): Promise<bigint>;
    isRegisteredToken(token: TokenAddress<C>): Promise<boolean>;
    getRegisteredTokens(): Promise<(((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) extends infer T ? T extends ((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) ? T extends "Solana" ? WormholeNamespace.PlatformToNativeAddressMapping[T] : never : never : never)[]>;
    private calculateNativeSwapRate;
    private getForeignContract;
    private getRegisteredToken;
    private getRedeemerConfig;
    private createUnsignedTx;
}
//# sourceMappingURL=automaticTokenBridge.d.ts.map