import { Platform, Chain, ChainAddress, ChainId, ChainsConfig, Contracts, Network, TokenBridge, TokenId } from '@wormhole-foundation/connect-sdk';
import { AnySolanaAddress, SolanaChains, SolanaPlatformType, SolanaUnsignedTransaction } from '@wormhole-foundation/connect-sdk-solana';
import { SolanaWormholeCore } from '@wormhole-foundation/connect-sdk-solana-core';
import { Program } from '@project-serum/anchor';
import { Connection } from '@solana/web3.js';
import { TokenBridge as TokenBridgeContract } from './tokenBridgeType';
import '@wormhole-foundation/connect-sdk-solana-core';
export declare class SolanaTokenBridge<N extends Network, C extends SolanaChains> implements TokenBridge<N, SolanaPlatformType, C> {
    readonly network: N;
    readonly chain: C;
    readonly connection: Connection;
    readonly contracts: Contracts;
    readonly chainId: ChainId;
    readonly coreBridge: SolanaWormholeCore<N, C>;
    readonly tokenBridge: Program<TokenBridgeContract>;
    constructor(network: N, chain: C, connection: Connection, contracts: Contracts);
    static fromRpc<N extends Network>(connection: Connection, config: ChainsConfig<N, Platform>): Promise<SolanaTokenBridge<N, SolanaChains>>;
    isWrappedAsset(token: AnySolanaAddress): Promise<boolean>;
    getOriginalAsset(token: AnySolanaAddress): Promise<TokenId>;
    hasWrappedAsset(token: TokenId): Promise<boolean>;
    getWrappedAsset(token: TokenId<Chain>): Promise<((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) extends infer T ? T extends ((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) ? T extends "Solana" ? WormholeNamespace.PlatformToNativeAddressMapping[T] : never : never : never>;
    isTransferCompleted(vaa: TokenBridge.TransferVAA): Promise<boolean>;
    getWrappedNative(): Promise<((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) extends infer T ? T extends ((C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C) extends "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] extends {
        [key: string]: unknown;
        [key: number]: unknown;
        [key: symbol]: unknown;
    } ? {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : {
        Acala: "Evm";
        Arbitrum: "Evm";
        Aurora: "Evm";
        Avalanche: "Evm";
        Base: "Evm";
        Bsc: "Evm";
        Celo: "Evm";
        Ethereum: "Evm";
        Fantom: "Evm";
        Gnosis: "Evm";
        Karura: "Evm";
        Klaytn: "Evm";
        Moonbeam: "Evm";
        Neon: "Evm";
        Oasis: "Evm";
        Optimism: "Evm";
        Polygon: "Evm";
        Rootstock: "Evm";
        Sepolia: "Evm";
        ArbitrumSepolia: "Evm";
        BaseSepolia: "Evm";
        OptimismSepolia: "Evm";
        Holesky: "Evm";
        Solana: "Solana";
        Pythnet: "Solana";
        Cosmoshub: "Cosmwasm";
        Evmos: "Cosmwasm";
        Injective: "Cosmwasm";
        Kujira: "Cosmwasm";
        Osmosis: "Cosmwasm";
        Sei: "Cosmwasm";
        Terra: "Cosmwasm";
        Terra2: "Cosmwasm";
        Wormchain: "Cosmwasm";
        Xpla: "Cosmwasm";
        Btc: "Btc";
        Algorand: "Algorand";
        Sui: "Sui";
        Aptos: "Aptos";
        Near: "Near";
    }[("Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky") & (C extends bigint ? `bigint(${C})` : C extends boolean ? `boolean(${C})` : C)] : never) ? T extends "Solana" ? WormholeNamespace.PlatformToNativeAddressMapping[T] : never : never : never>;
    createAttestation(token: AnySolanaAddress, payer?: AnySolanaAddress): AsyncGenerator<SolanaUnsignedTransaction<N, C>>;
    submitAttestation(vaa: TokenBridge.AttestVAA, payer?: AnySolanaAddress): AsyncGenerator<SolanaUnsignedTransaction<N, C>>;
    private transferSol;
    transfer(sender: AnySolanaAddress, recipient: ChainAddress, token: AnySolanaAddress | 'native', amount: bigint, payload?: Uint8Array): AsyncGenerator<SolanaUnsignedTransaction<N, C>>;
    private redeemAndUnwrap;
    private createAta;
    redeem(sender: AnySolanaAddress, vaa: TokenBridge.TransferVAA, unwrapNative?: boolean): AsyncGenerator<SolanaUnsignedTransaction<N, C>, void, unknown>;
    private createUnsignedTx;
}
//# sourceMappingURL=tokenBridge.d.ts.map